@@ -2,7 +2,7 @@
 package Tapper::MCP::Master;
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Wait for new testruns and start a new child when needed
-$Tapper::MCP::Master::VERSION = '5.0.2';
+$Tapper::MCP::Master::VERSION = '5.0.3';
 use 5.010;
         use Moose;
         use parent "Tapper::MCP";
@@ -76,7 +76,7 @@ sub cleanup_output_dir
         {
                 my ($self) = @_;
         CHILD: while ($self->dead_child) {
-                        $self->log->debug("Number of dead children is ".$self->dead_child);
+                        $self->log->debug("Number of dead testrun processes is ".$self->dead_child);
                         my $dead_pid = waitpid(-1, WNOHANG);  # don't use wait(); qx() sends a SIGCHLD and increases $self->deadchild, but wait() for the return value and thus our wait would block
 
                         $self->dead_child($self->dead_child - 1);
@@ -163,6 +163,7 @@ sub cleanup_output_dir
                         } else {
                                 $self->log->info("Testrun $id ($system) finished successfully");
                         }
+                        $self->scheduler->mark_job_as_finished($job);
                         exit 0;
                 } else {
 
